@@ -47,6 +47,10 @@ def get_parser():
         "-c", "--celsius", "--cel", "--centigrade",
         help="Temperature in degree celsius (default is Kelvin)",
         action="store_true")
+    parser.add_argument(
+        "--mb", "--hPa", "--millibar",
+        help="Pressure in millibar/hPa (default is Pascal)",
+        action="store_true")
 
     ###########################################################################
     # RIGB arguments
@@ -227,12 +231,20 @@ def dispatch_converter(args, input_file, output_file, stations):
     Reads the first character of the input file, and uses it to guess the
     format of the input file and dispatch the right converter.
     """
-    input_file_basename = os.path.basename(input_file)
-    if input_file_basename[-7:] == 'aws.dat' or input_file_basename[:8] == 'polenet_':
+    pol_scar = False  # Check if input file is from POLENET or SCAR network
+    with open(input_file) as stream:
+        stream.readline()  # Skip first line
+        if stream.readline().startswith("Operated by"):
+            pol_scar = True
+
+    if pol_scar:
         scar2nc.scar2nc(args, input_file, output_file)
     else:
         with open(input_file) as stream:
             char = stream.readline()[0]
+        if char == ' ':  # For PROMICE v03 files, the first character is blank space, so read the second character
+            with open(input_file) as stream:
+                char = stream.readline()[1]
 
         converters = {
             'D': gcnet2nc.gcnet2nc,
