@@ -1,6 +1,7 @@
 from datetime import datetime
 import os
 import re
+import sys
 import warnings
 
 import numpy as np
@@ -22,22 +23,28 @@ def init_dataframe(args, input_file):
 
     with open(input_file) as stream:
         for line in stream:
-            input_file_vars =[x.strip() for x in line.split(' ')]
+            input_file_vars =[x.strip() for x in line.split(' ') if x]
             break
 
     df, columns = common.load_dataframe('promice', input_file, 1, input_file_vars=input_file_vars)
     df.replace(check_na, np.nan, inplace=True)
+
     temperature_vars = ['ta', 'ta_hygroclip', 'ts',
                'tice1', 'tice2', 'tice3', 'tice4',
                'tice5', 'tice6', 'tice7', 'tice8',
                'temp_logger']
     if not args.celsius:
-        df.loc[:, temperature_vars] += common.freezing_point_temp
-    df.loc[:, ['pa']] *= common.pascal_per_millibar
-    df.loc[:, ['fan_current']] /= convert_current
+        df.loc[:, temperature_vars] += common.freezing_point_temp  # Convert units to Kelvin
+
+    pressure_vars = ['pa']
+    if not args.mb:
+        df.loc[:, pressure_vars] *= common.pascal_per_millibar  # Convert units to millibar/hPa
+
+    df.loc[:, ['fan_current']] /= convert_current  # Convert units to Ampere
+
     df = df.where((pd.notnull(df)), common.get_fillvalue(args))
 
-    return df, temperature_vars
+    return df, temperature_vars, pressure_vars
 
 
 def get_station(args, input_file, stations):
@@ -54,10 +61,17 @@ def get_station(args, input_file, stations):
                 aliases[b] = bits[-1]
 
     filename = os.path.basename(input_file)
+    count = 0
     for key, value in aliases.items():
         if key in filename:
+            count += 1
             return common.parse_station(args, stations[value])
 
+    if count == 0:
+        print("ERROR: Please check input file name. It should include station name e.g. KAN-B. Note that there is "
+              "'-' between KAN and B not '_'. This condition is only for PROMICE stations.")
+        sys.exit(1)
+
 
 def get_time_and_sza(args, dataframe, longitude, latitude):
     """Calculate additional time related variables"""
@@ -159,7 +173,7 @@ def convert_coordinates(args, dataframe):
 
 def promice2nc(args, input_file, output_file, stations):
     """Main function to convert PROMICE txt file to netCDF"""
-    df, temperature_vars = init_dataframe(args, input_file)
+    df, temperature_vars, pressure_vars = init_dataframe(args, input_file)
     ds = xr.Dataset.from_dataframe(df)
     ds = ds.drop('time')
 
@@ -190,7 +204,8 @@ def promice2nc(args, input_file, output_file, stations):
 
     comp_level = args.dfl_lvl
 
-    common.load_dataset_attributes('promice', ds, args, rigb_vars=rigb_vars, temperature_vars=temperature_vars)
+    common.load_dataset_attributes('promice', ds, args, rigb_vars=rigb_vars, temperature_vars=temperature_vars,
+                                   pressure_vars=pressure_vars)
     encoding = common.get_encoding('promice', common.get_fillvalue(args), comp_level, args)
 
     common.write_data(args, ds, output_file, encoding)
